/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VaultSecretsSecretConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the application the secret can be found in
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.72.1/docs/resources/vault_secrets_secret#app_name VaultSecretsSecret#app_name}
    */
    readonly appName: string;
    /**
    * The name of the secret
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.72.1/docs/resources/vault_secrets_secret#secret_name VaultSecretsSecret#secret_name}
    */
    readonly secretName: string;
    /**
    * The value of the secret
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/hcp/0.72.1/docs/resources/vault_secrets_secret#secret_value VaultSecretsSecret#secret_value}
    */
    readonly secretValue: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/hcp/0.72.1/docs/resources/vault_secrets_secret hcp_vault_secrets_secret}
*/
export declare class VaultSecretsSecret extends cdktf.TerraformResource {
    static readonly tfResourceType = "hcp_vault_secrets_secret";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/hcp/0.72.1/docs/resources/vault_secrets_secret hcp_vault_secrets_secret} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VaultSecretsSecretConfig
    */
    constructor(scope: Construct, id: string, config: VaultSecretsSecretConfig);
    private _appName?;
    get appName(): string;
    set appName(value: string);
    get appNameInput(): string | undefined;
    get id(): string;
    get organizationId(): string;
    get projectId(): string;
    private _secretName?;
    get secretName(): string;
    set secretName(value: string);
    get secretNameInput(): string | undefined;
    private _secretValue?;
    get secretValue(): string;
    set secretValue(value: string);
    get secretValueInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
